import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion";
import parse from "html-react-parser";
import styles from "./JobCardDescription.module.css";
import Image from "next/image";
import JobCardIconContainer from "./JobCardIconContainer";

interface JobPosting {
  title: string;
  logo: string;
  company: string;
  location: string;
  type: string;
  description: string;
  link: string;
  skills: {
    react: boolean;
    python: boolean;
    golang: boolean;
    svelte: boolean;
    nextjs: boolean;
    typescript: boolean;
    tailwind: boolean;
  };
}

export default async function JobCard(props: { job: JobPosting }) {
  const { title, logo, company, location, type, description, link, skills } =
    props.job;
  const parsedDescription = parse(description);
  const hasAnySkill = Object.values(skills).some((skill) => skill);

  return (
    <Accordion type="single" collapsible>
      <AccordionItem value="item-1">
        <AccordionTrigger>
          <div className="flex justify-between w-full">
            <div className="flex flex-row items-center gap-4">
              <Image
                className="max-h-12 w-auto"
                src={logo}
                alt={`${company}'s logo`}
                width={100}
                height={100}
              />
              <div className="flex flex-col justify-start">
                <h2 className="text-2xl text-left">{title}</h2>

                <div className="text-left items-center space-x-4">
                  <span className="">{company}</span>
                  <span className="text-sm text-stone-500">{location}</span>
                  <span className="text-sm text-stone-500">{type}</span>
                </div>
              </div>
            </div>
            <div className="flex justify-end items-center gap-2">
              {hasAnySkill && <JobCardIconContainer skills={skills} />}
            </div>
          </div>
        </AccordionTrigger>
        <AccordionContent>
          <div className={`py-4 ${styles.parsedDescription}`}>
            {parsedDescription}
          </div>
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  );
}
